@@ -1,6 +1,6 @@
 from celery import shared_task
 
-from . import cost_tracking, openstack, utils
+from . import cost_tracking, openstack, slurm, utils
 
 
 @shared_task(name='analytics.push_points')
@@ -12,4 +12,5 @@ def push_points():
     points.extend(openstack.get_tenants())
     points.extend(openstack.get_instances())
     points.extend(cost_tracking.get_total_cost())
+    points.extend(slurm.get_usage())
     utils.write_points(client, points)
