@@ -7,7 +7,12 @@ from . import models
 
 class ExpertProviderAdmin(admin.ModelAdmin):
     list_display = ('uuid', 'customer', 'created')
-    readonly_fields = ('customer', 'created')
+
+
+class ExpertRequestAdmin(admin.ModelAdmin):
+    list_display = ('uuid', 'project', 'state', 'created')
+    readonly_fields = ('project', 'created')
 
 
 admin.site.register(models.ExpertProvider, ExpertProviderAdmin)
+admin.site.register(models.ExpertRequest, ExpertRequestAdmin)
