@@ -1,5 +1,7 @@
 from __future__ import unicode_literals
 
+import copy
+
 from django.conf import settings
 from django.contrib.auth import get_user_model
 from django.db import transaction
@@ -16,6 +18,16 @@ from . import models, backend
 User = get_user_model()
 
 
+def render_issue_template(config_name, issue):
+    issue_settings = settings.WALDUR_SUPPORT.get('ISSUE', {})
+    if not issue_settings:
+        return ''
+
+    raw = issue_settings[config_name]
+    template = Template(raw)
+    return template.render(Context({'issue': issue}))
+
+
 class IssueSerializer(core_serializers.AugmentedSerializerMixin,
                       serializers.HyperlinkedModelSerializer):
     resource = core_serializers.GenericRelatedField(
@@ -48,7 +60,6 @@ class IssueSerializer(core_serializers.AugmentedSerializerMixin,
     is_reported_manually = serializers.BooleanField(
         initial=False, default=False, write_only=True,
         help_text=_('Set true if issue is created by regular user via portal.'))
-    issue_settings = settings.WALDUR_SUPPORT.get('ISSUE', {})
 
     class Meta(object):
         model = models.Issue
@@ -153,8 +164,8 @@ class IssueSerializer(core_serializers.AugmentedSerializerMixin,
         if project:
             validated_data['customer'] = project.customer
 
-        validated_data['description'] = self._render_template('description', validated_data)
-        validated_data['summary'] = self._render_template('summary', validated_data)
+        validated_data['description'] = render_issue_template('description', validated_data)
+        validated_data['summary'] = render_issue_template('summary', validated_data)
         return super(IssueSerializer, self).create(validated_data)
 
     def _render_template(self, config_name, issue):
@@ -258,7 +269,7 @@ class WebHookReceiverSerializer(serializers.Serializer):
             'impact': self._get_impact_field(fields=fields),
             'summary': fields['summary'],
             'priority': self._get_field_name(fields, 'priority'),
-            'description': fields['description'],
+            'description': fields['description'] or '',
             'type': fields['issuetype']['name'],
         }
 
@@ -321,7 +332,7 @@ class WebHookReceiverSerializer(serializers.Serializer):
     def _get_backend_comments(self, issue_key, fields):
         """
         Forms a dictionary of a backend comments where an id is a key and a comment body is a value.
-        :param issue_key: an issue key to look up for comments; 
+        :param issue_key: an issue key to look up for comments;
         :param fields: fields from issue in the response;
         :return: a dictionary of a backend comments with their ids as keys.
         """
@@ -414,10 +425,11 @@ class OfferingSerializer(structure_serializers.PermissionFieldFilteringMixin,
 
     class Meta(object):
         model = models.Offering
-        fields = ('url', 'uuid', 'name', 'project', 'type', 'state', 'type_label', 'price', 'created', 'modified',
-                  'issue', 'issue_name', 'issue_link', 'issue_key', 'issue_description', 'issue_uuid', 'issue_status',
+        fields = ('url', 'uuid', 'name', 'project', 'type', 'state', 'type_label', 'unit_price',
+                  'unit', 'created', 'modified', 'issue', 'issue_name', 'issue_link',
+                  'issue_key', 'issue_description', 'issue_uuid', 'issue_status',
                   'project_name', 'project_uuid', 'product_code', 'article_code')
-        read_only_fields = ('type_label', 'issue', 'price', 'state', 'product_code', 'article_code')
+        read_only_fields = ('type_label', 'issue', 'unit_price', 'unit', 'state', 'product_code', 'article_code')
         protected_fields = ('project', 'type')
         extra_kwargs = dict(
             url={'lookup_field': 'uuid', 'view_name': 'support-offering-detail'},
@@ -449,8 +461,11 @@ class ConfigurableSerializerMixin(object):
         the value itself has been provided in the create request.
     """
 
+    def _get_offerings_configuration(self):
+        return copy.deepcopy(settings.WALDUR_SUPPORT['OFFERINGS'])
+
     def _get_configuration(self, type):
-        return settings.WALDUR_SUPPORT['OFFERINGS'].get(type)
+        return self._get_offerings_configuration().get(type)
 
     def get_fields(self):
         result = super(ConfigurableSerializerMixin, self).get_fields()
@@ -463,7 +478,7 @@ class ConfigurableSerializerMixin(object):
 
         # choices have to be added dynamically so that unit tests can mock offering configuration.
         # otherwise it is always going to be a default set up.
-        result['type'] = serializers.ChoiceField(allow_blank=False, choices=settings.WALDUR_SUPPORT['OFFERINGS'].keys())
+        result['type'] = serializers.ChoiceField(allow_blank=False, choices=self._get_offerings_configuration().keys())
 
         return result
 
@@ -485,18 +500,20 @@ class ConfigurableSerializerMixin(object):
         return super(ConfigurableSerializerMixin, self).validate_empty_values(data)
 
     def _get_field_instance(self, attr_options):
-        filed_type = attr_options.get('type')
-        if filed_type is None or filed_type.lower() == 'string':
+        field_type = attr_options.get('type', '').lower()
+
+        if field_type == 'string':
             field = serializers.CharField(max_length=255, write_only=True)
-        elif filed_type.lower() == 'integer':
+        elif field_type == 'integer':
             field = serializers.IntegerField(write_only=True)
         else:
-            raise NotImplementedError('Type "%s" can not be serialized.' % type)
+            field = serializers.CharField(write_only=True)
+
         default_value = attr_options.get('default')
         if default_value:
             field.default = default_value
-            field.required = False
 
+        field.required = attr_options.get('required', False)
         field.label = attr_options.get('label')
         field.help_text = attr_options.get('help_text')
 
@@ -506,6 +523,9 @@ class ConfigurableSerializerMixin(object):
         result = []
 
         for key in configuration['order']:
+            if key not in validated_data:
+                continue
+
             label = configuration['options'].get(key, {})
             label_value = label.get('label', key)
             result.append('%s: \'%s\'' % (label_value, validated_data[key]))
@@ -515,6 +535,16 @@ class ConfigurableSerializerMixin(object):
 
         return '\n'.join(result)
 
+    def _get_extra(self, configuration, validated_data):
+        result = {
+            key: validated_data[key]
+            for key in configuration['order']
+            if key in validated_data
+        }
+        if 'description' in validated_data:
+            result['description'] = validated_data['description']
+        return result
+
 
 class OfferingCreateSerializer(ConfigurableSerializerMixin, OfferingSerializer):
     description = serializers.CharField(required=False, help_text=_('Description to add to the issue.'))
@@ -544,29 +574,36 @@ class OfferingCreateSerializer(ConfigurableSerializerMixin, OfferingSerializer):
         type = validated_data['type']
         offering_configuration = self._get_configuration(type)
         type_label = offering_configuration.get('label', type)
-        issue = models.Issue.objects.create(
+        issue_details = dict(
             caller=self.context['request'].user,
             project=project,
             customer=project.customer,
             type=settings.WALDUR_SUPPORT['DEFAULT_OFFERING_ISSUE_TYPE'],
             summary='Request for \'%s\'' % type_label,
-            description=self._form_description(offering_configuration, validated_data)
-        )
+            description=self._form_description(offering_configuration, validated_data))
+        issue_details['summary'] = render_issue_template('summary', issue_details)
+        issue_details['description'] = render_issue_template('description', issue_details)
+        issue = models.Issue.objects.create(**issue_details)
 
         offering = models.Offering.objects.create(
             issue=issue,
             project=issue.project,
             name=validated_data.get('name'),
-            type=type)
+            type=type,
+            product_code=offering_configuration.get('product_code', ''),
+            article_code=offering_configuration.get('article_code', ''),
+        )
 
         return offering
 
 
 class OfferingCompleteSerializer(serializers.Serializer):
-    price = serializers.DecimalField(max_digits=13, decimal_places=7)
+    unit_price = serializers.DecimalField(max_digits=13, decimal_places=7)
+    unit = serializers.ChoiceField(choices=models.Offering.Units.CHOICES, default=models.Offering.Units.PER_DAY)
 
     def update(self, instance, validated_data):
-        instance.price = validated_data['price']
+        instance.unit_price = validated_data['unit_price']
+        instance.unit = validated_data['unit']
         instance.state = models.Offering.States.OK
-        instance.save(update_fields=['state', 'price'])
+        instance.save(update_fields=['state', 'unit_price', 'unit'])
         return instance
